package com.ruoyi.web.controller.coffee;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.OrderLog;
import com.ruoyi.system.service.IOrderLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单日志Controller
 * 
 * @author ruoyi
 * @date 2022-04-28
 */
@RestController
@RequestMapping("/system/log")
public class OrderLogController extends BaseController
{
    @Autowired
    private IOrderLogService orderLogService;

    /**
     * 查询订单日志列表
     */
    @PreAuthorize("@ss.hasPermi('system:log:list')")
    @GetMapping("/list")
    public TableDataInfo list(OrderLog orderLog)
    {
        startPage();
        List<OrderLog> list = orderLogService.selectOrderLogList(orderLog);
        return getDataTable(list);
    }

    /**
     * 导出订单日志列表
     */
    @PreAuthorize("@ss.hasPermi('system:log:export')")
    @Log(title = "订单日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OrderLog orderLog)
    {
        List<OrderLog> list = orderLogService.selectOrderLogList(orderLog);
        ExcelUtil<OrderLog> util = new ExcelUtil<OrderLog>(OrderLog.class);
        util.exportExcel(response, list, "订单日志数据");
    }

    /**
     * 获取订单日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:log:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(orderLogService.selectOrderLogById(id));
    }

    /**
     * 新增订单日志
     */
    @PreAuthorize("@ss.hasPermi('system:log:add')")
    @Log(title = "订单日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OrderLog orderLog)
    {
        return toAjax(orderLogService.insertOrderLog(orderLog));
    }

    /**
     * 修改订单日志
     */
    @PreAuthorize("@ss.hasPermi('system:log:edit')")
    @Log(title = "订单日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OrderLog orderLog)
    {
        return toAjax(orderLogService.updateOrderLog(orderLog));
    }

    /**
     * 删除订单日志
     */
    @PreAuthorize("@ss.hasPermi('system:log:remove')")
    @Log(title = "订单日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(orderLogService.deleteOrderLogByIds(ids));
    }
}
